@@ -43,6 +43,7 @@ from RecordService import (
     TAccessPermissionScope,
     TGetDatabasesParams, TGetTablesParams, TPlanRequestParams,
     TExecTaskParams, TFetchParams, TNetworkAddress, TRecordFormat, TTypeId,
+    TGetPartitionNamesParams,
     TGetPartitionsParams,
     TRecordServiceException, TRequestType, RecordServiceWorker,
     # Internal-only exports (used by rest-server)
@@ -54,6 +55,7 @@ from RecordService import (
     TDelegationToken,
     TErrorCode,
     TExprType,
+    TExprNodeType,
     TInitApplicationParams,
     TObjectOpType,
     TJDBCDataset,
