@@ -15,7 +15,6 @@
 # specific language governing permissions and limitations
 # under the License.
 
-# pylint: disable=too-many-arguments
 # pylint: disable=unused-import
 
 """ Utilities for using thrift, including SASl support. """
@@ -29,11 +28,11 @@ import getpass
 from io import BytesIO as BufferIO
 import struct
 
-from thriftpy.thrift import TClient
-from thriftpy.protocol.binary import TBinaryProtocol  # noqa
-from thriftpy.transport import TSocket, TTransportException, TTransportBase  # noqa
-from thriftpy.transport.buffered import TBufferedTransport  # noqa
-from thriftpy.transport import readall
+from thriftpy2.thrift import TClient
+from thriftpy2.protocol.binary import TBinaryProtocol  # noqa
+from thriftpy2.transport import TSocket, TTransportException, TTransportBase # noqa
+from thriftpy2.transport.base import readall # noqa
+from thriftpy2.transport.buffered import TBufferedTransport  # noqa
 
 from okera._pure_sasl_client import SASLClient
 from okera._util import get_logger_and_init_null
@@ -62,7 +61,7 @@ def get_socket(host, port, use_ssl, ca_cert):
     if not use_ssl:
         return TSocket(host, port)
 
-    from thriftpy.transport.sslsocket import TSSLSocket
+    from thriftpy2.transport.sslsocket import TSSLSocket
     if ca_cert is None:
         return TSSLSocket(host, port, validate=False)
     return TSSLSocket(host, port, validate=True, cafile=ca_cert)
