@@ -29,11 +29,12 @@ import pytz
 import sqlparse
 
 from okera import context, _thrift_api
+from okera._thrift_api import TAttribute
 from okera._thrift_api import TAuthorizeQueryClient
 from okera._thrift_api import TAuthorizeQueryParams
+from okera._thrift_api import TDataRegConnection
 from okera._thrift_api import TRequestContext
 from okera._thrift_api import TTypeId, TConfigType
-from okera._thrift_api import TAttribute
 
 DEFAULT_PRESTO_HOST = os.environ['ODAS_TEST_HOST']
 DEFAULT_PRESTO_PORT = os.environ['ODAS_TEST_PORT_PRESTO_COORD_HTTPS']
@@ -62,6 +63,13 @@ elif 'CEREBRO_TEST_LEVEL' in os.environ:
     TEST_LEVEL = os.environ['CEREBRO_TEST_LEVEL']
 ROOT_TOKEN = os.environ['OKERA_HOME'] + '/integration/tokens/cerebro.token'
 
+OS_VERSION = None
+try:
+  import lsb_release
+  OS_VERSION = lsb_release.get_os_release()['RELEASE']
+except:
+  pass
+
 identity = lambda x: x
 
 def get_env_var(name, coercer, default):
@@ -681,6 +689,22 @@ class TestBase(unittest.TestCase):
         '''
         conn.execute_ddl(ddl % db)
 
+    def _get_snowflake_data_reg_connection_obj(self, name):
+        data_reg_connection = TDataRegConnection()
+        data_reg_connection.name = name
+        data_reg_connection.type = "JDBC"
+        data_reg_connection.data_source_path = None
+        data_reg_connection.jdbc_driver = "snowflake"
+        data_reg_connection.host = "vq85960.snowflakecomputing.com"
+        data_reg_connection.port = 0
+        data_reg_connection.user_key = "awssm://snowflake-partner-username"
+        data_reg_connection.password_key = "awssm://snowflake-partner-password"
+        data_reg_connection.default_catalog = "SNOWFLAKE_SAMPLE_DATA"
+        data_reg_connection.default_schema = "TPCH_SF1"
+        data_reg_connection.is_active = True
+        data_reg_connection.connection_properties = {'defaultDb':'TPCH_SF1'}
+        return data_reg_connection
+
     @staticmethod
     def _get_t_attribute_obj(namespace, key):
         attribute = TAttribute()
