@@ -2,19 +2,20 @@
 #
 # Tests that should run on any configuration. The server auth can be specified
 # as an environment variables before running this test.
+#
+# These tests require the identity service to be running.
 
 # pylint: disable=no-member
 # pylint: disable=protected-access
 # pylint: disable=too-many-public-methods
 # pylint: disable=bad-continuation
 # pylint: disable=bad-indentation
-# pylint: disable=too-many-arguments
 import time
 import unittest
 import string
 import random
 
-from okera import context
+from okera.tests import pycerebro_test_common as common
 
 TEST_DB = 'access_review_test_db'
 
@@ -97,9 +98,9 @@ def get_access(ctx, conn, expected_accesses=None, tries=5):
 class AccessReviewTest(unittest.TestCase):
 
     def test_basic_access_review(self):
-        ctx = context()
+        ctx = common.get_test_context()
         ctx.enable_token_auth(token_str='root')
-        with ctx.connect(host='localhost', port=12050) as conn:
+        with common.get_planner(ctx) as conn:
             conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % TEST_DB)
             conn.execute_ddl('CREATE DATABASE %s' % TEST_DB)
 
