@@ -409,6 +409,62 @@ class AttributesTest(common.TestBase):
             # Ensure this does not fail
             conn.execute_ddl('ALTER TABLE %s.test EXECUTE AUTOTAG' % (db))
 
+    def test_attribute_case(self):
+        db = 'attributes_case_test_db'
+        ctx = common.get_test_context()
+
+        permutations = ['vv', 'vV', 'Vv', 'VV']
+        with common.get_planner(ctx) as conn:
+            conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db)
+            conn.execute_ddl('CREATE DATABASE %s' % db)
+            conn.execute_ddl('CREATE TABLE %s.t(i int)' % db)
+
+            for c_tag in permutations:
+                conn.create_attribute('abac_test', c_tag)
+                #for obj in ['TABLE %s.tbl' % db, 'DATABASE %s' % db]:
+                for a_tag in permutations:
+                    for d_tag in permutations:
+                        # Table
+                        conn.execute_ddl('ALTER TABLE %s.t ADD ATTRIBUTE abac_test.%s' % \
+                            (db, a_tag))
+                        attrs = conn.list_datasets(db, name='t')[0].attribute_values
+                        self.assertEqual(1, len(attrs))
+                        self.assertEqual('vv', attrs[0].attribute.key)
+
+                        conn.execute_ddl('ALTER TABLE %s.t DROP ATTRIBUTE abac_test.%s' % \
+                            (db, d_tag))
+                        attrs = conn.list_datasets(db, name='t')[0].attribute_values
+                        self.assertTrue(attrs is None)
+
+                        # Column
+                        conn.execute_ddl(
+                            'ALTER TABLE %s.t ADD COLUMN ATTRIBUTE i abac_test.%s' % \
+                            (db, a_tag))
+                        ds = conn.list_datasets(db, name='t')[0]
+                        attrs = self.collect_column_attributes(ds)
+                        self.assertEqual(
+                            ['abac_test.vv'], attrs['attributes_case_test_db.t.i'])
+
+                        conn.execute_ddl(
+                            'ALTER TABLE %s.t DROP COLUMN ATTRIBUTE i abac_test.%s' % \
+                            (db, d_tag))
+                        ds = conn.list_datasets(db, name='t')[0]
+                        attrs = self.collect_column_attributes(ds)
+                        self.assertTrue(not attrs)
+
+                        # DB
+                        conn.execute_ddl(
+                            'ALTER DATABASE %s ADD ATTRIBUTE abac_test.%s' % \
+                            (db, a_tag))
+                        res = conn.execute_ddl('describe database %s' % db)
+                        self.assertTrue(['attributes', 'abac_test.vv'] in res)
+
+                        conn.execute_ddl(
+                            'ALTER DATABASE %s DROP ATTRIBUTE abac_test.%s' % \
+                            (db, d_tag))
+                        res = conn.execute_ddl('describe database %s' % db)
+                        self.assertTrue(['attributes', 'abac_test.vv'] not in res)
+
     def test_cascade(self):
         db = 'attributes_test_db'
         ctx = common.get_test_context()
