@@ -1,6 +1,7 @@
 # Copyright 2019 Okera Inc. All Rights Reserved.
 #
-# Some integration tests for auth in PyOkera
+# Some integration tests for auth in PyOkera.
+# This requires the presto container to be running.
 #
 # pylint: disable=global-statement
 # pylint: disable=no-self-use
@@ -168,7 +169,8 @@ class AuthTest(unittest.TestCase):
         ctx = common.get_test_context()
         with common.get_planner(ctx, dialect='presto') as conn:
             ctx.enable_token_auth(token_func=bad_then_good_func, user='foo')
-            results = conn.scan_as_json('select * from okera_sample.whoami', dialect='presto')
+            results = conn.scan_as_json(
+                'select * from okera_sample.whoami', dialect='presto')
             self.assertEqual(len(results), 1)
             self.assertEqual(results[0]['user'], 'foo')
 
@@ -176,7 +178,8 @@ class AuthTest(unittest.TestCase):
         ctx = common.get_test_context()
         with common.get_planner(ctx, dialect='presto') as conn:
             ctx.enable_token_auth(token_func=always_bad, token_str='foo')
-            results = conn.scan_as_json('select * from okera_sample.whoami', dialect='presto')
+            results = conn.scan_as_json(
+                'select * from okera_sample.whoami', dialect='presto')
             self.assertEqual(len(results), 1)
             self.assertEqual(results[0]['user'], 'foo')
 
@@ -185,7 +188,8 @@ class AuthTest(unittest.TestCase):
         with common.get_planner(ctx, dialect='presto') as conn:
             ctx.enable_token_auth(token_func=always_bad, user='foo')
             with pytest.raises(prestodb.exceptions.DatabaseError):
-                results = conn.scan_as_json('select * from okera_sample.whoami', dialect='presto')
+                results = conn.scan_as_json(
+                    'select * from okera_sample.whoami', dialect='presto')
                 # we should never get here
                 raise Exception()
 
@@ -194,6 +198,7 @@ class AuthTest(unittest.TestCase):
         with common.get_planner(ctx, dialect='presto') as conn:
             ctx.enable_token_auth(token_func=bad_twice_then_good_func, user='foo')
             with pytest.raises(prestodb.exceptions.DatabaseError):
-                results = conn.scan_as_json('select * from okera_sample.whoami', dialect='presto')
+                results = conn.scan_as_json(
+                    'select * from okera_sample.whoami', dialect='presto')
                 # we should never get here
                 raise Exception()
