@@ -41,13 +41,13 @@ else:
 SKIP_SCANS = common.get_bool_env_var('AUTH_TEST_SKIP_SCANS', False)
 AUTH_QUERY = SKIP_SCANS = common.get_bool_env_var('AUTH_TEST_AUTH_QUERY', False)
 
-class AuthorizationTest(unittest.TestCase):
+class AbacTest(common.TestBase):
     @classmethod
     def setUpClass(cls):
         """ Initializes one time state that is shared across test cases. This is used
             to speed up the tests. State that can be shared across (but still stable)
             should be here instead of __cleanup()."""
-        super(AuthorizationTest, cls).setUpClass()
+        super(AbacTest, cls).setUpClass()
         ctx = common.get_test_context()
         with common.get_planner(ctx) as conn:
             conn.delete_attribute('abac_auth_test', 'v1')
@@ -80,6 +80,13 @@ class AuthorizationTest(unittest.TestCase):
         self.__ddl(conn, "GRANT ROLE %s to GROUP %s" % \
             (ABAC_TRANSFORM_ROLE2, ABAC_TRANSFORM_USER2))
 
+    def __run(self, conn, sql, error_msg):
+        if error_msg:
+            with self.assertRaisesRegex(TRecordServiceException, error_msg):
+                conn.execute_ddl(sql)
+        else:
+            conn.execute_ddl(sql)
+
     def __convert_col(self, cols, idx):
         name = '`' + cols[idx].name + '`'
         type = cols[idx].type
@@ -989,5 +996,360 @@ class AuthorizationTest(unittest.TestCase):
 
                 self.__test_db(ctx, conn, db, True)
 
+    def test_fs_grant(self):
+        ctx = common.get_test_context()
+        db = 'test_fs_grant_db'
+        role = 'test_fs_grant_role'
+        user = 'test_fs_grant_user'
+        path = 's3://cerebrodata-test/empty'
+        ddl = "create external table %s.%s(i int) location '%s'"
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, [user])
+            self._recreate_test_db(conn, db)
+            # Test user has create on db, but may or may not on the path
+            conn.execute_ddl('GRANT CREATE ON DATABASE %s TO ROLE %s' % (db, role))
+
+            # Works as admin
+            conn.execute_ddl(ddl % (db, 't1', path))
+
+            # Not as test user
+            ctx.enable_token_auth(token_str=user)
+            with self.assertRaises(TRecordServiceException) as ex_ctx:
+                conn.execute_ddl(ddl % (db, 't2', path))
+            self.assertTrue(
+                "does not have privileges to execute 'SELECT' on: s3a://cerebrodata-test/empty" \
+                    in str(ex_ctx.exception),
+                msg=str(ex_ctx.exception))
+
+            # Do a server level grant, should cascade to URIs
+            ctx.disable_auth()
+            conn.execute_ddl('GRANT ALL ON CATALOG TO ROLE %s' % role)
+            self._recreate_test_db(conn, db)
+
+            # should work now
+            ctx.enable_token_auth(token_str=user)
+            conn.execute_ddl(ddl % (db, 't3', path))
+            conn.execute_ddl('describe %s.t3' % db)
+
+    def test_parametrized_grant(self):
+        """
+        Setup:
+        $ aws s3 ls --recursive s3://cerebrodata-test/user_dir_test/
+        2022-01-06 23:58:08          0 user_dir_test/user1/empty
+        2022-01-06 23:58:11          0 user_dir_test/user2/empty
+        2022-01-06 23:58:13          0 user_dir_test/user3/empty
+        2022-01-07 00:08:04          0 user_dir_test/user4/empty
+
+        Existing:
+        parametrized_test_db.user1_tbl
+        parametrized_test_db.user1_tbl
+        parametrized_test_db.user1_tbl
+        parametrized_test_db.user1_tbl
+
+        # Will create:
+        parametrized_db_user1.tbl
+        parametrized_db_user2.tbl
+        parametrized_db_user3.tbl
+        parametrized_db_user4.tbl
+        """
+
+        role = 'parametrized_user_role'
+        ctx = common.get_test_context()
+        db_prefix = 'parametrized_db'
+        db = 'parametrized_test_db'
+        users = ['user1', 'user2', 'user3', 'user4']
+
+        with common.get_planner(ctx) as conn:
+            result = conn.ls('s3://cerebrodata-test/user_dir_test/')
+            self.assertEqual(4, len(result))
+
+            self._recreate_test_role(conn, role, users)
+            self._recreate_test_db(conn, db)
+            self._recreate_test_db(conn, db_prefix + '_no_user')
+
+            for u in users:
+                conn.execute_ddl('DROP DATABASE IF EXISTS %s_%s CASCADE' % (db_prefix, u))
+                conn.execute_ddl('CREATE TABLE %s.%s_tbl(i int)' % (db, u))
+
+            for u in users:
+                ctx.enable_token_auth(token_str=u)
+                # No access to top level
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have access'):
+                    conn.ls('s3://cerebrodata-test/user_dir_test/')
+
+                # No access to to user
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have access'):
+                    conn.ls('s3://cerebrodata-test/user_dir_test/%s' % u)
+
+                # No access to create db or table
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have privileges'):
+                    conn.execute_ddl('CREATE DATABASE %s_%s' % (db_prefix, u))
+
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have privileges'):
+                    conn.execute_ddl('CREATE TABLE %s_%s.tbl(i int)' % (db_prefix, u))
+
+                # Try a per use table in the shared db
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have privileges'):
+                    conn.execute_ddl('DESCRIBE %s.%s_tbl' % (db, u))
+
+
+            # Set up parametrized grant
+            ctx.disable_auth()
+            conn.execute_ddl("GRANT ALL ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_dir_test/${user}', role))
+            conn.execute_ddl("GRANT ALL ON DATABASE `%s_%s` TO ROLE %s" %\
+                (db_prefix, '${user}', role))
+            conn.execute_ddl("GRANT ALL ON TABLE %s.`%s_tbl` TO ROLE %s" %\
+                (db, '${user}', role))
+            conn.execute_ddl("GRANT ALL ON DATABASE `%s_no_user` TO ROLE %s" %\
+                (db_prefix, role))
+            conn.execute_ddl('DROP DATABASE %s_no_user' % db_prefix)
+
+            for u in users:
+                ctx.enable_token_auth(token_str=u)
+                # No access to top level
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have access'):
+                    conn.ls('s3://cerebrodata-test/user_dir_test/')
+
+                # Access to this user
+                result = conn.ls('s3://cerebrodata-test/user_dir_test/%s' % u)
+                self.assertEqual(1, len(result))
+
+                # No access to create the database even with a create grant.
+                # create lets you create inside the object by default.
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have privileges'):
+                    conn.execute_ddl('CREATE DATABASE %s_no_user' % (db_prefix))
+
+                # No access to another user
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have access'):
+                    conn.ls('s3://cerebrodata-test/user_dir_test/user5')
+                conn.execute_ddl('CREATE DATABASE %s_%s' % (db_prefix, u))
+
+                # User can create table in person db
+                conn.execute_ddl('CREATE TABLE %s_%s.tbl(i int)' % (db_prefix, u))
+                # But not others
+                with self.assertRaisesRegex(TRecordServiceException,
+                                            'does not have privileges'):
+                    conn.execute_ddl(
+                        'CREATE TABLE %s_%s.tbl(i int)' % (db_prefix, 'user5'))
+
+                # Try a per use table in the shared db
+                conn.execute_ddl('DESCRIBE %s.%s_tbl' % (db, u))
+
+            # Manual for user4
+            ctx.enable_token_auth(token_str='user4')
+            # Access to this user
+            result = conn.ls('s3://cerebrodata-test/user_dir_test/user4')
+            self.assertEqual(1, len(result))
+            result = conn.ls('s3://cerebrodata-test/user_dir_test/user4/a')
+            self.assertEqual(0, len(result))
+            # No access to another user
+            with self.assertRaisesRegex(TRecordServiceException,
+                                        'does not have access'):
+                conn.ls('s3://cerebrodata-test/user_dir_test/user')
+
+    def test_create_error(self):
+        ctx = common.get_test_context()
+        db = 'test_create_error'
+        role = 'test_create_error_role'
+        user = 'test_create_error_user'
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, [user])
+            self._recreate_test_db(conn, db)
+            # Test user has create on db, but may or may not on the path
+            conn.execute_ddl('GRANT SELECT ON DATABASE %s TO ROLE %s' % (db, role))
+
+            ctx.enable_token_auth(token_str=user)
+            with self.assertRaisesRegex(TRecordServiceException,
+                  "does not have privileges to execute 'CREATE' on the catalog."):
+                conn.execute_ddl('CREATE DATABASE %s_2' % db)
+            with self.assertRaisesRegex(TRecordServiceException,
+                  "does not have privileges to execute 'CREATE' on: test_create_error"):
+                conn.execute_ddl('CREATE TABLE %s.t(i int)' % db)
+
+    def test_home_directory_scenario(self):
+        ctx = common.get_test_context()
+        users = ['user1', 'user2']
+        role = 'users_role'
+        db_prefix = 'users'
+        s3_prefix = 's3://cerebrodata-test/user_home_test'
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, users)
+
+            # Set up the user home database. The user has most access on their home db
+            conn.execute_ddl("GRANT SELECT ON DATABASE `%s_%s` TO ROLE %s" %\
+                (db_prefix, '${user}', role))
+            conn.execute_ddl("GRANT CREATE ON DATABASE `%s_%s` TO ROLE %s" %\
+                (db_prefix, '${user}', role))
+            conn.execute_ddl("GRANT DROP ON DATABASE `%s_%s` TO ROLE %s" %\
+                (db_prefix, '${user}', role))
+            conn.execute_ddl("GRANT ALTER ON DATABASE `%s_%s` TO ROLE %s" %\
+                (db_prefix, '${user}', role))
+
+            # Allow reading and creating in the user S3 home directory
+            conn.execute_ddl("GRANT SELECT ON URI '%s/%s' TO ROLE %s" %\
+                (s3_prefix, '${user}', role))
+            conn.execute_ddl("GRANT INSERT ON URI '%s/%s' TO ROLE %s" %\
+                (s3_prefix, '${user}', role))
+
+            def run(sql, error_msg):
+                self.__run(conn, sql, error_msg)
+
+            for me in users:
+                if me == 'user1':
+                    you = 'user2'
+                else:
+                    you = 'user1'
+
+                ctx.enable_token_auth(token_str=me)
+                run('DROP DATABASE IF EXISTS %s_%s CASCADE' % (db_prefix, me), None)
+                run('CREATE DATABASE %s_%s' % (db_prefix, me), None)
+                run("CREATE EXTERNAL TABLE %s_%s.t1(i int) LOCATION '%s/%s'" % \
+                    (db_prefix, me, s3_prefix, me), None)
+                run("ALTER TABLE %s_%s.t1 SET LOCATION '%s/%s'" % \
+                    (db_prefix, me, s3_prefix, me), None)
+                # Non-external tables should fail, it should require delete
+                run("CREATE TABLE %s_%s.t2(i int) LOCATION '%s/%s'" % \
+                    (db_prefix, me, s3_prefix, me), 'does not have privileges')
+
+                ctx.enable_token_auth(token_str=you)
+                run('DROP DATABASE IF EXISTS %s_%s' % (db_prefix, me),
+                    'does not have privileges')
+                run("CREATE EXTERNAL TABLE %s_%s.t(i int) LOCATION '%s/%s'" % \
+                    (db_prefix, me, s3_prefix, me), 'does not have privileges')
+                run("CREATE EXTERNAL TABLE %s_%s.t(i int) LOCATION '%s/%s'" % \
+                    (db_prefix, me, s3_prefix, you), 'does not have privileges')
+
+                # Try a URI grant the user does not have access to with parametrized user
+                run("GRANT ALL ON URI '%s/%s' TO ROLE %s" %\
+                    (s3_prefix, '${user}', role), 'does not have privileges')
+                run("GRANT SELECT ON URI '%s/%s' TO ROLE %s" %\
+                    (s3_prefix, '${user}', role), 'does not have privileges')
+
+            # Give this user ALL/DELETE on the URI. This should let us make non-external
+            # tables
+            for perm in ['ALL', 'DELETE']:
+                ctx.disable_auth()
+                conn.execute_ddl("GRANT %s ON URI '%s/%s' TO ROLE %s" %\
+                    (perm, s3_prefix, '${user}', role))
+                ctx.enable_token_auth(token_str='user1')
+                run("DROP TABLE IF EXISTS %s_%s.t2" % (db_prefix, 'user1'), None)
+                run("CREATE TABLE %s_%s.t2(i int) LOCATION '%s/%s/must-be-empty'" % \
+                    (db_prefix, 'user1', s3_prefix, 'user1'), None)
+
+                # Revoke the write grant, should no longer be able to alter
+                ctx.disable_auth()
+                conn.execute_ddl("REVOKE %s ON URI '%s/%s' FROM ROLE %s" %\
+                    (perm, s3_prefix, '${user}', role))
+                ctx.enable_token_auth(token_str='user1')
+                run("ALTER TABLE %s_%s.t2 SET LOCATION '%s/%s/must-be-empty'" % \
+                    (db_prefix, 'user1', s3_prefix, 'user1'), 'does not have privileges')
+
+    def test_grant_parametrized1(self):
+        ctx = common.get_test_context()
+        user = 'user1'
+        role = 'fs_grant_role'
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, [user])
+
+            def run(sql, error_msg):
+                self.__run(conn, sql, error_msg)
+
+            # This should fail
+            ctx.enable_token_auth(token_str=user)
+            run("GRANT ALL ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1', role),
+                'does not have privileges')
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1', role),
+                'does not have privileges')
+
+            # Grant SELECT with GRANT with parametrized user
+            ctx.disable_auth()
+            conn.execute_ddl("GRANT SELECT ON URI '%s' TO ROLE %s WITH GRANT OPTION" %\
+                ('s3://cerebrodata-test/user_grant_test/home/${user}', role))
+            conn.execute_ddl("GRANT MANAGE_PERMISSIONS ON ROLE %s TO ROLE %s" %\
+                (role, role))
+
+            # This should fail
+            ctx.enable_token_auth(token_str=user)
+            run("GRANT ALL ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1', role),
+                'does not have privileges')
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1', role), None)
+
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1/abc', role), None)
+            # Subdir works
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1/abc', role), None)
+            # Parametrized subdir
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user1/${user}', role), None)
+
+            # Another user dir does not
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/user2/', role),
+                'does not have privileges')
+            # Or parent
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/', role),
+                'does not have privileges')
+            # Or parametrized on parent
+            run("GRANT SELECT ON URI '%s' TO ROLE %s" %\
+                ('s3://cerebrodata-test/user_grant_test/home/${user}', role),
+                'does not have privileges')
+
+    def test_transform_priorities(self):
+        # This assumes a test setup where rs.mask3() > rs.mask2() > all others in
+        # udf priorities
+        ctx = common.get_test_context()
+        user = 'user'
+        role = 'transform_priority_role'
+        tbl = 'abac_db.all_types'
+        tag = 'abac.string_col'
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, [user])
+
+            # Transform with zero
+            ctx.disable_auth()
+            conn.execute_ddl(
+                'GRANT SELECT ON TABLE %s TRANSFORM %s WITH zero() TO ROLE %s' % \
+                (tbl, tag, role))
+            ctx.enable_token_auth(token_str=user)
+            df = conn.scan_as_json(tbl)
+            print(df)
+            self.assertEqual('', df[0]['varchar_col'])
+
+            # Transform with mask2, should take precedence
+            ctx.disable_auth()
+            conn.execute_ddl(
+                'GRANT SELECT ON TABLE %s TRANSFORM %s WITH rs.mask2() TO ROLE %s' % \
+                (tbl, tag, role))
+
+            ctx.enable_token_auth(token_str=user)
+            df = conn.scan_as_json(tbl)
+            print(df)
+            self.assertEqual('xxxxxx', df[0]['varchar_col'])
+
+            # Transform with uppercase, should take precedence
+            ctx.disable_auth()
+            conn.execute_ddl(
+                'GRANT SELECT ON TABLE %s TRANSFORM %s WITH rs.uppercase() TO ROLE %s' % \
+                (tbl, tag, role))
+            ctx.enable_token_auth(token_str=user)
+            df = conn.scan_as_json(tbl)
+            print(df)
+            self.assertEqual('VCHAR1', df[0]['varchar_col'])
+
 if __name__ == "__main__":
     unittest.main()
