@@ -170,7 +170,6 @@ class BasicTest(common.TestBase):
         planner = common.get_planner(ctx)
         result = planner.execute_ddl("show databases")
         planner.close()
-        print(result)
         self.assertTrue(len(result) > 3)
 
     def test_plan(self):
@@ -180,6 +179,18 @@ class BasicTest(common.TestBase):
         self.assertEqual(1, len(plan.tasks))
         planner.close()
 
+    def test_list_partition_names(self):
+        ctx = common.get_test_context()
+        planner = common.get_planner(ctx)
+        result1 = planner.list_partition_names("partdb", "ymdata")
+        # ensure correct number of results
+        self.assertTrue(len(result1) == 4)
+        result2 = planner.list_partition_names("partdb", "ymdata")
+        planner.close()
+        result2.sort()
+        #ensure the partition list is always returned sorted
+        self.assertTrue(result1 == result2)
+
     def test_task_split(self):
         ctx = common.get_test_context()
         planner = common.get_planner(ctx)
@@ -534,11 +545,9 @@ class BasicTest(common.TestBase):
 
             ## Test1: parquet table.
             test_table = "bytes_type_show_created"
-            res = planner.execute_ddl("SHOW CREATE TABLE rs_complex_parquet.bytes_type")
-            self.assertEqual(len(res), 1)
+            create_ddl = planner.execute_ddl("SHOW CREATE TABLE rs_complex_parquet.bytes_type")
 
             ## extract the output, which is a create table statement. Modify
-            create_ddl = res[0][0]
             create_ddl = create_ddl.replace("bytes_type", test_table)
             self.assertTrue(test_table in create_ddl)
             planner.execute_ddl("DROP TABLE IF EXISTS rs_complex_parquet." + test_table)
@@ -561,11 +570,10 @@ class BasicTest(common.TestBase):
 
 
             ## Test2: customer avro table
-            res = planner.execute_ddl("SHOW CREATE TABLE customer.acxiom_cnsmr_xref")
+            create_ddl = planner.execute_ddl("SHOW CREATE TABLE customer.acxiom_cnsmr_xref")
             test_table = "acxiom_cnsmr_xref_show_created"
 
             ## extract the output, which is a create table statement. Modify
-            create_ddl = res[0][0]
             create_ddl = create_ddl.replace("customer.acxiom_cnsmr_xref",
                                                       "customer." + test_table)
             planner.execute_ddl("DROP TABLE IF EXISTS customer." + test_table)
@@ -586,6 +594,20 @@ class BasicTest(common.TestBase):
             drop_table_ddl = "DROP TABLE customer." + test_table
             planner.execute_ddl(drop_table_ddl)
 
+            ## Test3: opencsv table
+            test_table = "alltypes_s3_opencsv_created"
+            create_ddl = planner.execute_ddl(
+                "SHOW CREATE TABLE rs.alltypes_s3_opencsv")
+            create_ddl = create_ddl.replace("rs.alltypes_s3_opencsv",
+                                            "rs." + test_table)
+            planner.execute_ddl("DROP TABLE IF EXISTS rs." + test_table)
+            planner.execute_ddl(create_ddl)
+            self.assertTrue(
+                "ROW FORMAT SERDE 'org.apache.hadoop.hive.serde2.OpenCSVSerde'" in create_ddl)
+            sql = 'SELECT * FROM rs.' + test_table
+            query_result = planner.scan_as_json(sql)
+            self.assertEqual(len(query_result), 2)
+
     def test_get_datasets_databases_with_privilege(self):
         ATTR = ['priv_filter_test', 'attr1']
         DB1 = 'test_access_db1'
@@ -736,7 +758,8 @@ class BasicTest(common.TestBase):
             conn.execute_ddl("drop crawler if exists okera_quarantine")
             conn.execute_ddl("drop database if exists okera_quarantine")
             conn.execute_ddl("create database okera_quarantine")
-            conn.execute_ddl("create crawler okera_quarantine source 's3://cerebrodata-test/empty/'")
+            conn.execute_ddl(
+                "create crawler okera_quarantine source 's3://cerebrodata-test/empty/'")
             result = conn.list_databases()
             assert "okera_quarantine" not in result
             assert "_okera_crawler_okera_quarantine" not in result
@@ -819,7 +842,6 @@ class BasicTest(common.TestBase):
                 pytest.fail("Expected to fail parsing unparseable view %s.%s"
                     % (test_db, test_view))
             except TRecordServiceException as ex:
-                print(ex)
                 self.assertTrue("AnalysisException" in ex.detail)
                 self.assertTrue("TableLoadingException" in ex.detail)
                 self.assertTrue(
@@ -836,7 +858,6 @@ class BasicTest(common.TestBase):
                 pytest.fail("Expected to fail parsing unparseable view %s.%s"
                     % (test_db, test_view))
             except TRecordServiceException as ex:
-                print(ex)
                 self.assertTrue("AnalysisException" in ex.detail)
                 self.assertTrue("TableLoadingException" in ex.detail)
                 self.assertTrue(
@@ -853,7 +874,6 @@ class BasicTest(common.TestBase):
               pytest.fail("Expected to fail parsing unparseable view %s.%s"
                     % (test_db, test_view))
             except TRecordServiceException as ex:
-                print(ex)
                 self.assertTrue("AnalysisException" in ex.detail)
                 self.assertTrue("TableLoadingException" in ex.detail)
                 self.assertTrue(
@@ -1056,6 +1076,139 @@ class BasicTest(common.TestBase):
                 "s3://cerebrodata-test/dataset-rename-test", include_views=True)
             assert 's3://cerebrodata-test/dataset-rename-test' not in res
 
+    def test_add_drop_partitions(self):
+        DB = "test_add_drop_partitions_db"
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_db(conn, DB)
+            conn.execute_ddl(
+            '''
+              CREATE EXTERNAL TABLE %s.part(i int) partitioned by (j int)
+              LOCATION 's3://cerebrodata-test/empty';
+            ''' % DB)
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part ADD PARTITION(j=1)
+              LOCATION 's3://cerebrodata-test/empty'
+              ''' % DB)
+
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(2, len(results))
+
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part ADD
+              PARTITION(j=2) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=3) LOCATION 's3://cerebrodata-test/empty'
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(4, len(results))
+
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part DROP
+              PARTITION(j=1)
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(3, len(results))
+
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part DROP
+              PARTITION(j=2)
+              PARTITION(j=3)
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # Must the totals row
+            self.assertEqual(1, len(results))
+
+            # Try some failures
+            with self.assertRaises(_thrift_api.TRecordServiceException):
+                conn.execute_ddl(
+                  '''
+                  ALTER TABLE %s.part DROP
+                  PARTITION(j=2)
+                  PARTITION(j=3)
+                  ''' % DB)
+            with self.assertRaises(_thrift_api.TRecordServiceException):
+                conn.execute_ddl(
+                  '''
+                  ALTER TABLE %s.part DROP
+                  PARTITION(j=1)
+                  ''' % DB)
+
+    def test_drop_partial_partition_spec(self):
+        DB = "test_add_drop_partial_spec_db"
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_db(conn, DB)
+            conn.execute_ddl(
+            '''
+              CREATE EXTERNAL TABLE %s.part(i int) partitioned by (j int, k int)
+              LOCATION 's3://cerebrodata-test/empty';
+            ''' % DB)
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part ADD
+              PARTITION(j=1, k=1) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=1, k=2) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=1, k=3) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=2, k=1) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=2, k=2) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=2, k=3) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=3, k=1) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=3, k=2) LOCATION 's3://cerebrodata-test/empty'
+              PARTITION(j=3, k=3) LOCATION 's3://cerebrodata-test/empty'
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(10, len(results))
+
+            # Drop all j=1s
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part DROP PARTITION(j=1)
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(7, len(results))
+
+            # Drop all k's=3 and a specific one
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part DROP
+                PARTITION(j=2, k=1)
+                PARTITION(k=3)
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # One extra totals row
+            self.assertEqual(4, len(results))
+
+            with self.assertRaises(_thrift_api.TRecordServiceException):
+                conn.execute_ddl(
+                  '''ALTER TABLE %s.part DROP PARTITION(j=1)''' % DB)
+            with self.assertRaises(_thrift_api.TRecordServiceException):
+                conn.execute_ddl(
+                  '''
+                  ALTER TABLE %s.part DROP
+                    PARTITION(j=1)
+                    PARTITION(k=3)''' % DB)
+
+            # Drop all the remaining, including some no-op specs
+            conn.execute_ddl(
+              '''
+              ALTER TABLE %s.part DROP
+                PARTITION(j=1)
+                PARTITION(j=2)
+                PARTITION(j=3)
+                PARTITION(j=4)
+              ''' % DB)
+            results = conn.execute_ddl('SHOW PARTITIONS %s.part' % DB)
+            # Just totals row
+            self.assertEqual(1, len(results))
 
 if __name__ == "__main__":
     unittest.main()
