@@ -30,22 +30,24 @@ CONNECTION_PRIVILEGES = [
     (TAccessPermissionLevel.USE, True, False, False, True),
 ]
 
-def get_connection_as_root(conn, name):
+def get_connection_as_root(conn, name, resolve_creds=None):
     drc = TDataRegConnection()
     drc.name = name
 
     orig_user = conn.ctx._get_user()
     conn.ctx.disable_auth()
-    connections = conn.manage_data_reg_connection("GET", drc).connections
+    connections = conn.manage_data_reg_connection("GET", drc,
+            resolve_creds=resolve_creds).connections
     conn.ctx.enable_token_auth(token_str=orig_user)
 
     return connections[0]
 
-def get_connection(conn, name):
+def get_connection(conn, name, resolve_creds=None):
     drc = TDataRegConnection()
     drc.name = name
 
-    connections = conn.manage_data_reg_connection("GET", drc).connections
+    connections = conn.manage_data_reg_connection("GET", drc,
+            resolve_creds=resolve_creds).connections
     return connections[0]
 
 def delete_connection(conn, name):
@@ -80,7 +82,7 @@ def manage_crawler(conn, name):
 
     return conn.manage_crawler(drc)
 
-class DataRegistrationTest(unittest.TestCase):
+class DataRegistrationTest(common.TestBase):
     @classmethod
     def setUpClass(cls):
         """ Initializes one time state that is shared across test cases. This is used
@@ -153,22 +155,6 @@ class DataRegistrationTest(unittest.TestCase):
         data_reg_connection.connection_properties = {'ssl':'False'}
         return data_reg_connection
 
-    def _get_snowflake_data_reg_connection_obj(self, name):
-        data_reg_connection = TDataRegConnection()
-        data_reg_connection.name = name
-        data_reg_connection.type = "JDBC"
-        data_reg_connection.data_source_path = None
-        data_reg_connection.jdbc_driver = "snowflake"
-        data_reg_connection.host = "vq85960.snowflakecomputing.com"
-        data_reg_connection.port = 0
-        data_reg_connection.user_key = "awssm://snowflake-partner-username"
-        data_reg_connection.password_key = "awssm://snowflake-partner-password"
-        data_reg_connection.default_catalog = "SNOWFLAKE_SAMPLE_DATA"
-        data_reg_connection.default_schema = "TPCH_SF1"
-        data_reg_connection.is_active = True
-        data_reg_connection.connection_properties = {'defaultDb':'TPCH_SF1'}
-        return data_reg_connection
-
     def _verify_mssql_table_schema(self, ret_list_jdbc_datasets, \
         ret_jdbc_schema, ret_jdbc_table):
         for dataset in ret_list_jdbc_datasets:
@@ -434,6 +420,14 @@ class DataRegistrationTest(unittest.TestCase):
             # get test
             drcs = conn.manage_data_reg_connection("GET", drc)
             self.assertTrue(len(drcs.connections) == 1)
+            self.assertEqual(drcs.connections[0].user_key, 'awssm://postgres-jdbcpsqltest-username')
+            self.assertEqual(drcs.connections[0].password_key, 'awssm://postgres-jdbcpsqltest-password')
+
+            # get test (with resolved credentials)
+            drcs = conn.manage_data_reg_connection("GET", drc, resolve_creds=True)
+            self.assertTrue(len(drcs.connections) == 1)
+            self.assertEqual(drcs.connections[0].user_key, 'cerebro')
+            self.assertEqual(drcs.connections[0].password_key, 'cerebro1')
 
             # list with filters works as expected
             drcs = conn.manage_data_reg_connection(
@@ -524,6 +518,73 @@ class DataRegistrationTest(unittest.TestCase):
             drcs = conn.manage_data_reg_connection("CREATE", drc)
             self.assertTrue(len(drcs.connections) == 1)
 
+    def test_drc_crud_saas_direct_credentials(self):
+        """ In SaaS environment, users can enter the credentials directly i.e. in plain
+            text. Okera generates secret key_ids for such credentials and stores them
+            in a secret store. BE is not supposed to return the actual password
+            to UI for security. Instead, BE would return password field as blank.
+        """
+        MYSQL_CXN = 'test_drc_crud_saas_direct_credentials_mysql_conn'
+        PSQL_CXN  = 'test_drc_crud_saas_direct_credentials_psql_conn'
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
+            ##### CREATE
+            # create a connection with direct_credentials=True
+            # The returned conn object should have clear text username but blank password.
+            conn.execute_ddl('DROP DATACONNECTION IF EXISTS %s' % (MYSQL_CXN))
+            drc = self._get_mysqltest_data_reg_connection_obj(MYSQL_CXN)
+            drc.user_key = "cerebro"
+            drc.password_key = "cerebro1"
+            drcs = conn.manage_data_reg_connection("CREATE", drc, direct_credentials=True)
+            self.assertTrue(len(drcs.connections) == 1)
+            self.assertEqual(drcs.connections[0].user_key, 'cerebro')
+            self.assertEqual(drcs.connections[0].password_key, '')
+
+            ##### GET
+            # Fetch the newly created connection with direct_credentials=False
+            # It should return secret key_ids for username and password instead of
+            # clear-text username and blank password.
+            drcs = conn.manage_data_reg_connection("GET", drc, direct_credentials=False)
+            self.assertTrue(len(drcs.connections) == 1)
+            self.assertTrue('%s/mysql/user' % MYSQL_CXN in drcs.connections[0].user_key)
+            self.assertTrue('%s/mysql/password' % MYSQL_CXN in drcs.connections[0].password_key)
+
+            ##### GET and UPDATE (modify any field other than password)
+            # Fetch the same connection with direct_credentials=True so that
+            # the returned conn object has clear-text username but blank password.
+            # Now, update conn object and modify field(s) other than the password (ex. default_catalog)
+            # BE checks the password field and as it is blank, it uses the existing
+            # password with the modified connection object to store it in Okera.
+            drc = conn.manage_data_reg_connection("GET", drc, direct_credentials=True).connections[0]
+            self.assertEqual(drc.user_key, 'cerebro')
+            self.assertEqual(drc.password_key, '')
+            self.assertEqual(drc.default_catalog, 'jdbc_test')
+            # modify default_catalog and update
+            drc.default_catalog = 'jdbc_demo'
+            drcs = conn.manage_data_reg_connection("UPDATE", drc, direct_credentials=True)
+            self.assertTrue(len(drcs.connections) == 1)
+            self.assertEqual(drcs.connections[0].default_catalog, 'jdbc_demo')
+            self.assertEqual(drcs.connections[0].user_key, 'cerebro')
+            self.assertEqual(drcs.connections[0].password_key, '')
+
+            ##### GET and UPDATE (modify the password field)
+            # Fetch the updated connection with direct_credentials=True so that
+            # the returned conn object has clear-text username but blank password.
+            # Now, update conn object and modify the password (here we are updating it to
+            # same value, otherwise connection to MySql would fail).
+            # BE checks the password field and as it is not blank, it uses the new
+            # password and store it in Okera.
+            drc = conn.manage_data_reg_connection("GET", drc, direct_credentials=True).connections[0]
+            drc.password_key = 'cerebro1'
+            drcs = conn.manage_data_reg_connection("UPDATE", drc, direct_credentials=True)
+            self.assertTrue(len(drcs.connections) == 1)
+            self.assertEqual(drcs.connections[0].default_catalog, 'jdbc_demo')
+            self.assertEqual(drcs.connections[0].user_key, 'cerebro')
+            self.assertEqual(drcs.connections[0].password_key, '')
+            ##### DELETE
+            drcs = conn.manage_data_reg_connection("DELETE", drc, direct_credentials=True)
+            self.assertTrue(len(drcs.connections) == 0)
+
     def test_drc_testconnection_as_admin(self):
         MYSQL_CXN = 'test_drc_testconnection_as_admin_mysql_conn'
         SNWFLK_CXN = 'test_drc_testconnection_as_admin_snwflk_conn'
