@@ -138,7 +138,6 @@ class DenyTest(common.TestBase):
 
             params = _thrift_api.TGetRoleParams()
             params.role_name = TEST_ROLE
-            params.include_privilege_props = True
             params.include_role_history = True
             result = conn._underlying_client().GetRole(params)
             role = result.role
@@ -322,98 +321,6 @@ class DenyTest(common.TestBase):
                 "SELECT * FROM %s.okera_kv_store WHERE value like %s" % (TEST_DB, like_clause))
             self.assertTrue(not data)
 
-    def test_grant_props(self):
-        ctx = common.get_test_context()
-        with common.get_planner(ctx) as conn:
-            self.__cleanup(conn)
-            props = " POLICYPROPERTIES('name'='me', 'description'='awesome!')"
-            conn.execute_ddl("GRANT SELECT ON CATALOG TO ROLE %s %s" % (TEST_ROLE, props))
-
-            params = _thrift_api.TListRolesParams()
-            params.role_name_substring = TEST_ROLE
-            params.include_privilege_props = True
-            roles = conn._underlying_client().ListRoles(params)
-            self.assertEqual(len(roles.roles), 1)
-            role = roles.roles[0]
-            self.assertEqual(len(role.privileges), 1)
-            priv = role.privileges[0]
-            self.assertEqual(priv.privilege_type, TPrivilegeType.GRANT)
-            self.assertEqual(priv.privilege_name, 'server=server1->action=SELECT')
-            # ID is auto-generated, it should be there
-            self.assertTrue('id' in priv.props)
-            id1 = priv.props['id']
-            del priv.props['id']
-            print(id1)
-            self.assertEqual(priv.props, {'name':'me', 'description':'awesome!'})
-
-            # check that getRole API also returns the props
-            params = _thrift_api.TGetRoleParams()
-            params.role_name = TEST_ROLE
-            params.include_privilege_props = True
-            role = conn._underlying_client().GetRole(params).role
-            self.assertEqual(len(role.privileges), 1)
-            priv = role.privileges[0]
-            # ID is auto-generated, it should be there
-            self.assertEqual(priv.privilege_type, TPrivilegeType.GRANT)
-            self.assertTrue('id' in priv.props)
-            id2 = priv.props['id']
-            del priv.props['id']
-            self.assertEqual(priv.privilege_name, 'server=server1->action=SELECT')
-            self.assertEqual(priv.props, {'name':'me', 'description':'awesome!'})
-
-            # IDs should match
-            self.assertEqual(id1, id2)
-
-            # Another grant, generate new ID
-            props = " POLICYPROPERTIES('name'='me2', 'description'='awesome!')"
-            conn.execute_ddl("GRANT SELECT ON DATABASE okera_sample TO ROLE %s %s" %\
-                (TEST_ROLE, props))
-            params = _thrift_api.TListRolesParams()
-            params.role_name_substring = TEST_ROLE
-            params.include_privilege_props = True
-            roles = conn._underlying_client().ListRoles(params)
-            self.assertEqual(len(roles.roles), 1)
-            role = roles.roles[0]
-            self.assertEqual(len(role.privileges), 2)
-            priv = role.privileges[0]
-            self.assertEqual(priv.privilege_type, TPrivilegeType.GRANT)
-            self.assertEqual(priv.privilege_name,
-                             'server=server1->db=okera_sample->action=SELECT')
-            # ID is auto-generated, it should be there
-            self.assertTrue('id' in priv.props)
-            id3 = priv.props['id']
-            del priv.props['id']
-            self.assertEqual(priv.props, {'name':'me2', 'description':'awesome!'})
-            self.assertTrue(id1 != id3)
-
-            priv = role.privileges[1]
-            self.assertEqual(priv.privilege_type, TPrivilegeType.GRANT)
-            self.assertEqual(priv.privilege_name, 'server=server1->action=SELECT')
-            # ID is auto-generated, it should be there
-            self.assertTrue('id' in priv.props)
-            id4 = priv.props['id']
-            del priv.props['id']
-            self.assertEqual(priv.props, {'name':'me', 'description':'awesome!'})
-            self.assertEqual(id1, id4)
-
-            # Issue an alter
-            props = " POLICYPROPERTIES('name'='me3', 'id'='%s')" % id4
-            conn.execute_ddl("ALTER %s" % props)
-
-            roles = conn._underlying_client().ListRoles(params)
-            self.assertEqual(len(roles.roles), 1)
-            role = roles.roles[0]
-            self.assertEqual(len(role.privileges), 2)
-            priv = role.privileges[1]
-            self.assertEqual(priv.privilege_type, TPrivilegeType.GRANT)
-
-            # Should get same ID but different value
-            self.assertTrue('id' in priv.props)
-            id5 = priv.props['id']
-            del priv.props['id']
-            self.assertEqual(priv.props, {'name':'me3'})
-            self.assertEqual(id4, id5)
-
     def test_restrict_filter(self):
         ctx = common.get_test_context()
         with common.get_planner(ctx) as conn:
