@@ -23,7 +23,7 @@ from okera._thrift_api import (
     TListFilesOp, TListFilesParams
 )
 
-import okera_cli.plugin.boto as okera_boto
+import okera_fs_aws.plugin.boto as okera_boto
 
 import botocore
 import boto3
@@ -46,15 +46,21 @@ BOTO_FS_ROLE = 'test_boto_role'
 BOTO_FS_USER = 'testbotouser1'
 BOTO_FS_USER_NO_ACCESS = 'testbotouser2'
 BOTO_FS_USER_ROOT = 'root'
+MODE='endpoint'
 
-USER_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL)
-USER_S3_CLIENT = USER_SESSION.client('s3', verify=False, region_name='us-west-2')
+if not MODE or MODE == 'endpoint':
+    endpoint = ACCESS_PROXY_URL
+else:
+    endpoint = "s3.us-west-2.amazonaws.com"
 
-USER_NO_ACCESS_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER_NO_ACCESS, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL)
-USER_NO_ACCESS_S3_CLIENT = USER_NO_ACCESS_SESSION.client('s3', verify=False, region_name='us-west-2')
+USER_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL, MODE)
+USER_S3_CLIENT = USER_SESSION.client('s3', verify=False, region_name='us-west-2', endpoint_url=endpoint)
 
-USER_ROOT_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER_ROOT, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL)
-USER_ROOT_S3_CLIENT = USER_ROOT_SESSION.client('s3', verify=False, region_name='us-west-2')
+USER_NO_ACCESS_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER_NO_ACCESS, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL, MODE)
+USER_NO_ACCESS_S3_CLIENT = USER_NO_ACCESS_SESSION.client('s3', verify=False, region_name='us-west-2', endpoint_url=endpoint)
+
+USER_ROOT_SESSION = okera_boto.okera_session(boto3.session.Session(), BOTO_FS_USER_ROOT, TOKEN_CONFIG_SOURCE, REST_SERVER_URL, ACCESS_PROXY_URL, MODE)
+USER_ROOT_S3_CLIENT = USER_ROOT_SESSION.client('s3', verify=False, region_name='us-west-2', endpoint_url=endpoint)
 
 def authorize_uri(planner, user, action, uri):
     params = TListFilesParams()
@@ -64,7 +70,7 @@ def authorize_uri(planner, user, action, uri):
     params.authorize_only = True
     return planner.service.client.ListFiles(params)
 
-class FsTest(unittest.TestCase):
+class FsTest(common.TestBase):
     def test_grant(self):
         ctx = common.get_test_context()
         planner = common.get_planner(ctx)
