@@ -118,11 +118,11 @@ class ListCatalogsTest(unittest.TestCase):
                 "GRANT ROLE %s TO GROUP %s" % (ROLE, USER),
 
                 # First, grant some CATALOG-only things
-                "GRANT CREATE_AS_OWNER ON CATALOG TO ROLE %s" % (ROLE),
                 "GRANT CREATE_CRAWLER_AS_OWNER ON CATALOG TO ROLE %s" % (ROLE),
                 "GRANT VIEW_AUDIT ON CATALOG TO ROLE %s" % (ROLE),
 
                 # Grant some privileges at all data levels
+                "GRANT CREATE_AS_OWNER ON CATALOG TO ROLE %s" % (ROLE),
                 "GRANT CREATE ON DATABASE %s TO ROLE %s" % (DB, ROLE),
                 "GRANT VIEW_COMPLETE_METADATA ON TABLE %s TO ROLE %s" % (TBL1, ROLE),
                 "GRANT SELECT(col1) ON TABLE %s TO ROLE %s" % (TBL1, ROLE),
@@ -147,15 +147,15 @@ class ListCatalogsTest(unittest.TestCase):
             assert TAccessPermissionLevel.VIEW_AUDIT in access_levels[TAccessPermissionScope.SERVER]
 
             # Check the database permissions
-            assert len(access_levels[TAccessPermissionScope.DATABASE]) == 4
+            assert len(access_levels[TAccessPermissionScope.DATABASE]) == 5
             assert TAccessPermissionLevel.VIEW_AUDIT in access_levels[TAccessPermissionScope.DATABASE]
             assert TAccessPermissionLevel.CREATE in access_levels[TAccessPermissionScope.DATABASE]
             assert TAccessPermissionLevel.VIEW_COMPLETE_METADATA in access_levels[TAccessPermissionScope.DATABASE]
             assert TAccessPermissionLevel.SELECT in access_levels[TAccessPermissionScope.DATABASE]
+            assert TAccessPermissionLevel.CREATE_AS_OWNER in access_levels[TAccessPermissionScope.DATABASE]
 
             # Check the crawler permissions
-            assert len(access_levels[TAccessPermissionScope.CRAWLER]) == 2
-            assert TAccessPermissionLevel.VIEW_AUDIT in access_levels[TAccessPermissionScope.CRAWLER]
+            assert len(access_levels[TAccessPermissionScope.CRAWLER]) == 1
             assert TAccessPermissionLevel.DROP in access_levels[TAccessPermissionScope.CRAWLER]
 
 if __name__ == "__main__":
