@@ -14,6 +14,7 @@ import os
 #from datetime import datetime
 from okera.tests import pycerebro_test_common as common
 from okera._thrift_api import (TAttribute, TAttributeMatchLevel, TAccessPermissionLevel)
+from time import perf_counter
 
 TEST_USER = 'list_dbs_test_user'
 TEST_ROLE = 'list_dbs_test_role'
@@ -32,12 +33,6 @@ class ListDatabasesTest(unittest.TestCase):
         """
         super(ListDatabasesTest, cls).setUpClass()
 
-    def _get_t_attribute_obj(self, namespace, key):
-        attribute = TAttribute()
-        attribute.attribute_namespace = namespace
-        attribute.key = key
-        return attribute
-
     def test_list_databases_basic(self):
         USER = 'mktg_analyst'
         ctx = common.get_test_context()
@@ -57,6 +52,23 @@ class ListDatabasesTest(unittest.TestCase):
                                             limit=10, page_token=None)
             self.assertTrue(len(result.databases) == 10)
 
+            # Verify that when 'names_only' flag is set, no other metadata
+            # (like attributes, datasets count, db access levels etc) is populated except
+            # db_name
+            result = conn.list_databases_v2(name_pattern_filter='*tpc*',
+                                            limit=10, page_token=None, names_only=True)
+
+            returned_dbs = []
+            for database in result.databases:
+                returned_dbs.append(database.name)
+            self.assertTrue(len(result.databases) == 10)
+            for database in result.databases:
+                self.assertTrue(database.name in returned_dbs)
+                self.assertTrue(database.datasets_count == 0)
+                self.assertTrue(len(database.attribute_values) == 0)
+                self.assertTrue(database.access_levels is None)
+                assert database.has_grant is False
+
             result = conn.list_databases_v2(name_pattern_filter='okera_sample|rs',
                                             limit=10, page_token=None)
             self.assertTrue(len(result.databases) == 2)
@@ -94,6 +106,17 @@ class ListDatabasesTest(unittest.TestCase):
                 assert TAccessPermissionLevel.SELECT not in database.access_levels
             self.assertTrue(len(result.databases) == 1)
 
+            # Now verify that when 'names_only' flag is set, no other metadata
+            # (like attributes, datasets count, db access levels etc) is populated except
+            # db_name
+            result = conn.list_databases_v2(exact_names_filter=['temp_database'],
+                                            limit=10, page_token=None, names_only=True)
+            for database in result.databases:
+                self.assertTrue(database.name == ['temp_database'])
+                self.assertTrue(database.datasets_count == 0)
+                self.assertTrue(database.access_levels is None)
+            self.assertTrue(len(result.databases) == 1)
+
             # Drop temp_database
             ctx.enable_token_auth(token_str='root')
             conn.execute_ddl('DROP DATABASE IF EXISTS temp_database CASCADE')
@@ -178,9 +201,9 @@ class ListDatabasesTest(unittest.TestCase):
 
             # Create TAttribute objects required for testing
             attributes = []
-            attr1_db_level = self._get_t_attribute_obj('test_namespace', 'test_key1')
-            attr1_tab_level = self._get_t_attribute_obj('test_namespace', 'test_key2')
-            attr1_col_level = self._get_t_attribute_obj('test_namespace', 'test_key3')
+            attr1_db_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key1')
+            attr1_tab_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key2')
+            attr1_col_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key3')
 
             # should return the database: db1
             # Input tag is on DATABASE level and Match_Level = DATABASE_ONLY
@@ -266,9 +289,9 @@ class ListDatabasesTest(unittest.TestCase):
             conn.assign_attribute('test_namespace', 'test_key6', db4, 't4', 'c4')
 
             attributes = []
-            attr2_db_level = self._get_t_attribute_obj('test_namespace', 'test_key4')
-            attr3_tab_level = self._get_t_attribute_obj('test_namespace', 'test_key5')
-            attr4_col_level = self._get_t_attribute_obj('test_namespace', 'test_key6')
+            attr2_db_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key4')
+            attr3_tab_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key5')
+            attr4_col_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key6')
             attributes.append(attr2_db_level)
             attributes.append(attr3_tab_level)
             attributes.append(attr4_col_level)
@@ -376,7 +399,7 @@ class ListDatabasesTest(unittest.TestCase):
             conn.assign_attribute('test_namespace', 'test_key7', db7, 't7', 'c7')
 
             attributes = []
-            attr7_all_level = self._get_t_attribute_obj('test_namespace', 'test_key7')
+            attr7_all_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key7')
             attributes.append(attr7_all_level)
 
             # should return the database: db5
@@ -449,6 +472,37 @@ class ListDatabasesTest(unittest.TestCase):
             self.assertTrue([db6] in returned_dbs)
             self.assertTrue([db7] in returned_dbs)
 
+            ########## Test for 'names_only flag ###########
+            # Test to verify that when 'names_only' flag is set, no other metadata
+            # (like attributes, datasets count, db access levels etc.) is populated except db_name.
+            # Also, the flag should work with all the filters. Here, we are testing it
+            # with tags filter.
+
+            # names_only flag is not set, result should populate all the metadata
+            result = conn.list_databases_v2( tags=attributes,
+                tag_match_level=TAttributeMatchLevel.DATABASE_ONLY)
+
+            self.assertTrue(len(result.databases) == 1)
+            for database in result.databases:
+                self.assertTrue(database.name == [db5])
+                self.assertTrue(database.datasets_count == 1)
+                self.assertTrue(len(database.attribute_values) == 1)
+                self.assertTrue(len(database.access_levels) == 1)
+                assert TAccessPermissionLevel.ALL in database.access_levels
+                assert database.has_grant is True
+
+            # names_only flag is set, result should NOT populate any metadata except db_name
+            result = conn.list_databases_v2( tags=attributes,
+                tag_match_level=TAttributeMatchLevel.DATABASE_ONLY, names_only=True)
+
+            self.assertTrue(len(result.databases) == 1)
+            for database in result.databases:
+                self.assertTrue(database.name == [db5])
+                self.assertTrue(database.datasets_count == 0)
+                self.assertTrue(len(database.attribute_values) == 0)
+                self.assertTrue(database.access_levels is None)
+                assert database.has_grant is False
+
             # drop databases
             conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db5)
             conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db6)
@@ -504,7 +558,19 @@ class ListDatabasesTest(unittest.TestCase):
                 assert TAccessPermissionLevel.INSERT in database.access_levels
                 assert TAccessPermissionLevel.CREATE_AS_OWNER not in \
                     database.access_levels
-                assert database.has_grant
+                assert database.has_grant is True
+
+            # Now verify that when 'names_only' flag is set, no other metadata
+            # (like attributes, datasets count, db access levels etc) is populated except
+            # db_names
+            result = conn.list_databases_v2(exact_names_filter=[db1], names_only=True)
+
+            self.assertTrue(len(result.databases) == 1)
+            for database in result.databases:
+                self.assertTrue(database.name == [db1])
+                self.assertTrue(database.datasets_count == 0)
+                self.assertTrue(database.access_levels is None)
+                assert database.has_grant is False
 
             # Switch back to admin and create a database with no table and no privileges
             # It should inherit catalog privileges (CREATE, SHOW but not CREATE_AS_OWNER)
@@ -600,5 +666,48 @@ class ListDatabasesTest(unittest.TestCase):
             conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db3)
             conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % db4)
 
+    @unittest.skip("This is one-time test to gather perf stats for names_only flag." \
+        "New test/s would be added later to test performance of the listDatabases() api.")
+    def test_list_databases_perf_test_for_names_only_flag(self):
+        """ Test to verify that the listDatabases() api is fast enough with names_only flag
+            even if there are several thousand databases, each containing multiple tables.
+        """
+        DB  = 'perf_test_for_names_only_flag'
+        TBL = 'table'
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
+            # create test role and assign it to a group
+            conn.execute_ddl('DROP ROLE IF EXISTS %s'% TEST_ROLE)
+            conn.execute_ddl('CREATE ROLE %s'% TEST_ROLE)
+            conn.execute_ddl('GRANT ROLE %s TO GROUP %s' % (TEST_ROLE, TEST_USER))
+
+            start = perf_counter()
+            for i in range(0, 2000):
+                conn.execute_ddl('DROP DATABASE IF EXISTS %s CASCADE' % (DB + str(i+1)))
+                conn.execute_ddl('CREATE DATABASE %s' % (DB + str(i+1)))
+                for j in range(0, 5):
+                    conn.execute_ddl('CREATE TABLE %s.%s(c1 int, c2 int)' \
+                        % ((DB + str(i+1)), (TBL + str(j+1))))
+                conn.execute_ddl('GRANT SELECT ON TABLE %s.%s to ROLE %s' \
+                    % ((DB + str(i+1)), (TBL + str(j+1)), TEST_ROLE))
+            end = perf_counter()
+            print("\nElapsed Time in seconds for Creating DBs and Tables: %s" % (end - start))
+
+            # Test to record elapsed time for listDatabases() api without names_only flag
+            start = perf_counter()
+            ctx.enable_token_auth(token_str=TEST_USER)
+            result = conn.list_databases_v2(limit=10100)
+            end = perf_counter()
+            print("\nElapsed Time in seconds listDatabases() api w/o names_only flag: %s" % (end - start))
+            print(len(result.databases))
+
+            # Test to record elapsed time for listDatabases() api with names_only flag
+            start = perf_counter()
+            ctx.enable_token_auth(token_str=TEST_USER)
+            result = conn.list_databases_v2(limit=10100, names_only=True)
+            end = perf_counter()
+            print("\nElapsed Time in seconds listDatabases() api with names_only flag: %s" % (end - start))
+            print(len(result.databases))
+
 if __name__ == "__main__":
     unittest.main()
