@@ -138,12 +138,6 @@ class ListDatasetsTest(unittest.TestCase):
         request.count = count
         return conn._underlying_client().GetDatasets(request).datasets
 
-    def _get_t_attribute_obj(self, namespace, key):
-        attribute = TAttribute()
-        attribute.attribute_namespace = namespace
-        attribute.key = key
-        return attribute
-
     def test_tag_filter(self):
         """ Test for multi-tag filter
         """
@@ -170,9 +164,9 @@ class ListDatasetsTest(unittest.TestCase):
 
             # Create TAttribute objects required for testing
             attributes = []
-            attr1_db_level = self._get_t_attribute_obj('test_namespace', 'test_key1')
-            attr2_tab_level = self._get_t_attribute_obj('test_namespace', 'test_key2')
-            attr3_col_level = self._get_t_attribute_obj('test_namespace', 'test_key3')
+            attr1_db_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key1')
+            attr2_tab_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key2')
+            attr3_col_level = common.TestBase._get_t_attribute_obj('test_namespace', 'test_key3')
 
             # No Table should be returned.
             # Input tag is on DATABASE level and Match_Level = TABLE_ONLY
@@ -699,9 +693,9 @@ class ListDatasetsTest(unittest.TestCase):
             # Test user has 'ALL' on DB2 but no access on DB1
 
             # Create TAttribute objects required for testing
-            T_TAG1 = self._get_t_attribute_obj(NAMESPACE, TAG1)
-            T_TAG2 = self._get_t_attribute_obj(NAMESPACE, TAG2)
-            T_NON_EXISTING_TAG = self._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
+            T_TAG1 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG1)
+            T_TAG2 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG2)
+            T_NON_EXISTING_TAG = common.TestBase._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
 
             #  ********** Run tests as Root User ************
             ctx.enable_token_auth(token_str=ROOT_USER)
@@ -843,9 +837,9 @@ class ListDatasetsTest(unittest.TestCase):
             # Test user has 'ALL' on DB2 but no access on DB1
 
             # Create TAttribute objects required for testing
-            T_TAG1 = self._get_t_attribute_obj(NAMESPACE, TAG1)
-            T_TAG2 = self._get_t_attribute_obj(NAMESPACE, TAG2)
-            T_NON_EXISTING_TAG = self._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
+            T_TAG1 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG1)
+            T_TAG2 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG2)
+            T_NON_EXISTING_TAG = common.TestBase._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
 
             #  ********** Run tests as Root User ************
             ctx.enable_token_auth(token_str=ROOT_USER)
@@ -967,9 +961,9 @@ class ListDatasetsTest(unittest.TestCase):
             # Test user has 'ALL' on DB2 but no access on DB1
 
             # Create TAttribute objects required for testing
-            T_TAG1 = self._get_t_attribute_obj(NAMESPACE, TAG1)
-            T_TAG2 = self._get_t_attribute_obj(NAMESPACE, TAG2)
-            T_NON_EXISTING_TAG = self._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
+            T_TAG1 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG1)
+            T_TAG2 = common.TestBase._get_t_attribute_obj(NAMESPACE, TAG2)
+            T_NON_EXISTING_TAG = common.TestBase._get_t_attribute_obj(NAMESPACE, 'non_existing_tag')
 
             #  ********** Run tests as Root User ************
             ctx.enable_token_auth(token_str=ROOT_USER)
