@@ -25,23 +25,32 @@
 |     scan_as_json     | Wide table w/ many attrs | many_attrs_user | 499.488 | 490.157 | 512.780 | 772.903 | 772.903 |  100  |
 |      get_schema      | Wide table w/ many attrs | many_attrs_user | 442.111 | 438.563 | 451.890 | 503.797 | 503.797 |  100  |
 +----------------------+--------------------------+-----------------+---------+---------+---------+---------+---------+-------+
+
++--------------------+------------------+----------+---------+---------+---------+---------+---------+-------+
+|        rpc         |       name       |   user   |   mean  |   50%   |   90%   |   99%   |   max   | iters |
++--------------------+------------------+----------+---------+---------+---------+---------+---------+-------+
+| list_dataset_names | Many wide tables |  admin   |  15.462 |  14.772 |  16.967 |  24.237 |  24.237 |   50  |
+| list_dataset_names | Many wide tables | testuser | 259.072 | 250.976 | 283.031 | 481.884 | 481.884 |   50  |
++--------------------+------------------+----------+---------+---------+---------+---------+---------+-------+
 """
 import unittest
 import pytest
 
+from okera import policy_sync
 from okera import _thrift_api
 from okera._thrift_api import (
     TAccessPermissionLevel,
     TAccessPermissionScope,
     TAttributeMatchLevel,
     TAuthorizeQueryClient,
+    TGetDatasetsParams,
     TPlanRequestParams,
-    TRequestType
+    TRequestType,
 )
 from okera.tests import create_test_data
 from okera.tests import pycerebro_test_common as common
 
-from sfproxy_test import get_snowflake_proxy_test_context, get_snowflake_proxy
+from sf_test import get_snowflake_test_context, get_snowflake
 
 ATTR = "perf_test.attr1"
 DB = "python_perf_test_db"
@@ -132,12 +141,16 @@ class PerfTest(common.TestBase):
             for i in range(total_roles):
                 role_name = role_prefix + str(i)
                 user_name = user_prefix + str(i)
-                conn.execute_ddl("CREATE ROLE IF NOT EXISTS %s WITH GROUPS %s" % (role_name, user_name))
+                conn.execute_ddl("CREATE ROLE IF NOT EXISTS %s WITH GROUPS %s" % \
+                                 (role_name, user_name))
                 conn.execute_ddl("""
                 GRANT IF NOT EXISTS SELECT ON DATABASE %s
                 HAVING ATTRIBUTE IN (%s)
                 TO ROLE %s
-                POLICYPROPERTIES('enabled'='true', 'start_datetime'='543453453', 'end_datetime'='543453459')
+                POLICYPROPERTIES(
+                    'enabled'='true',
+                    'start_datetime'='543453453',
+                    'end_datetime'='543453459')
                 """ % (DB, ATTR, role_name))
                 conn.execute_ddl("""
                 GRANT IF NOT EXISTS SELECT ON TABLE %s.%s
@@ -175,19 +188,11 @@ class PerfTest(common.TestBase):
 
             t_params = _thrift_api.TListRolesParams()
             t_params.role_name_substring = role_prefix
-            PERF.measure(list(t_params, total_roles), "Listing Roles w/role name substring filter",
+            PERF.measure(list(t_params, total_roles),
+                         "Listing Roles w/role name substring filter",
                          "admin", "ListRoles")
 
-    @unittest.skipIf(not PERF.run_perf_snowflake(), "Skipping snowflake perf tests")
-    def test_measure_snowflake_speed_of_light(self):
-        sf_ctx = get_snowflake_proxy_test_context()
-
-        setup_ddls_params = {
-            'conn' : 'snowflake_connection_demo',
-            'group' : sf_ctx.username,
-            'role' : 'test_perf_sf_role',
-            'db' : 'test_perf_sf',
-        }
+    def _init_snowflake_setup(self, conn, ddls_params):
         setup_ddls = [
             "DROP DATABASE IF EXISTS {db} CASCADE INCLUDING PERMISSIONS",
             "CREATE DATABASE {db}",
@@ -230,11 +235,24 @@ class PerfTest(common.TestBase):
             "GRANT ROLE {role} TO GROUP {group}",
             "GRANT SELECT ON DATABASE {db} TO ROLE {role}",
         ]
+
+        for ddl_tmpl in setup_ddls:
+            ddl = ddl_tmpl.format(**ddls_params)
+            conn.execute_ddl(ddl)
+
+    @unittest.skipIf(not PERF.run_perf_snowflake(), "Skipping snowflake perf tests")
+    def test_measure_snowflake_speed_of_light(self):
+        sf_ctx = get_snowflake_test_context()
+        setup_ddls_params = {
+            'conn' : 'snowflake_connection_demo',
+            'group' : sf_ctx.username,
+            'role' : 'test_perf_sf_role',
+            'db' : 'test_perf_sf',
+        }
+
         planner_ctx = common.get_test_context()
         with common.get_planner(planner_ctx) as conn:
-            for ddl_tmpl in setup_ddls:
-                ddl = ddl_tmpl.format(**setup_ddls_params)
-                conn.execute_ddl(ddl)
+            self._init_snowflake_setup(conn, setup_ddls_params)
 
         def conn_query(conn):
             def get():
@@ -243,10 +261,42 @@ class PerfTest(common.TestBase):
                 assert len(res.get('rowset')) == 1
             return get
 
-        with get_snowflake_proxy(sf_ctx) as conn:
+        with get_snowflake(sf_ctx) as conn:
             conn.query_request("USE ROLE {}".format(sf_ctx.user_role))
             PERF.measure(conn_query(conn), "sfproxy: speed of light",
-                        sf_ctx.username, "sfproxy_query_request")
+                         sf_ctx.username, "sfproxy_query_request")
+
+    @unittest.skipIf(not PERF.run_perf_snowflake(), "Skipping snowflake perf tests")
+    def test_measure_snowflake_generate_policy_sync(self):
+        sf_ctx = get_snowflake_test_context(username='SFV3ADMIN')
+        setup_ddls_params = {
+            'conn' : 'snowflake_connection_demo',
+            'group' : sf_ctx.username,
+            'role' : 'test_perf_sf_role',
+            'db' : 'test_perf_sf',
+        }
+
+        planner_ctx = common.get_test_context()
+        with common.get_planner(planner_ctx) as conn:
+            self._init_snowflake_setup(conn, setup_ddls_params)
+            request = TGetDatasetsParams()
+            request.dataset_names = ['{}.{}'.format('test_perf_sf', 'patient')]
+            request.with_schema = True
+            okera_tbl = conn.service.client.GetDatasets(request).datasets[0]
+
+        with get_snowflake(sf_ctx) as conn:
+            users = policy_sync.get_snowflake_users(conn, before_role='ACCOUNTADMIN')
+
+        def generate(conn):
+            def get():
+                res = policy_sync.generate_policies(
+                    conn, users, 'test_perf_sf', 'patient', okera_tbl)
+                assert res is not None
+            return get
+
+        with common.get_planner(planner_ctx) as conn:
+            PERF.measure(generate(conn), "generate policy sync (all sf users)",
+                         'admin', "generate_policies")
 
     @unittest.skipIf(not PERF.run_perf(), "Skipping perf tests")
     def test_wide_table_with_attributes(self):
@@ -378,7 +428,8 @@ class PerfTest(common.TestBase):
                             print("shashi : %s" % database.name)
                         assert ([DB] in returned_dbs)
                     if tags is not None:
-                        result = conn.list_databases_v2(tags=tags, tag_match_level=match_level)
+                        result = conn.list_databases_v2(
+                            tags=tags, tag_match_level=match_level)
                         assert len(result.databases) >= 1
                 return get
 
@@ -392,7 +443,8 @@ class PerfTest(common.TestBase):
                          "admin", "list_databases_v2")
             PERF.measure(list_db(privilege=priv), "Privilege filter",
                          "admin", "list_databases_v2")
-            PERF.measure(list_db(tags=[attr], match_level=TAttributeMatchLevel.DATABASE_PLUS),
+            PERF.measure(list_db(tags=[attr],
+                         match_level=TAttributeMatchLevel.DATABASE_PLUS),
                          "Attributes filter", "admin", "list_databases_v2")
 
             ctx.enable_token_auth(token_str=TEST_USER)
@@ -402,7 +454,8 @@ class PerfTest(common.TestBase):
                          TEST_USER, "list_databases_v2")
             PERF.measure(list_db(privilege=priv), "Privilege filter",
                          TEST_USER, "list_databases_v2")
-            PERF.measure(list_db(tags=[attr], match_level=TAttributeMatchLevel.DATABASE_PLUS),
+            PERF.measure(list_db(tags=[attr],
+                         match_level=TAttributeMatchLevel.DATABASE_PLUS),
                          "Attributes filter", TEST_USER, "list_databases_v2")
 
     @unittest.skipIf(not PERF.run_perf(), "Skipping perf tests")
@@ -446,6 +499,79 @@ class PerfTest(common.TestBase):
                          TEST_USER2, "list_datasets")
             #PERF.measure(list(TEST_USER3), "multiple wide tables in db",
             #             TEST_USER3, "list_datasets")
+
+    @unittest.skipIf(not PERF.run_perf(), "Skipping perf tests")
+    def test_measure_recover_partitions(self):
+        db = 'perf_test_trial_analytics'
+        ctx = common.get_test_context()
+        with common.get_planner(ctx) as conn:
+            def recover():
+                self._recreate_test_db(conn, db)
+                conn.execute_ddl('''
+                    CREATE EXTERNAL TABLE %s.audit_logs(
+                      request_time STRING
+                    )
+                    PARTITIONED BY (tenant string, ymd string)
+                    STORED AS JSON
+                    LOCATION 's3://okera-trial-us-west-2-e71015d/tenants/logs/audit/'
+                    ''' % db)
+                conn.execute_ddl('''
+                    CREATE EXTERNAL TABLE %s.web_analytics(
+                      event_time STRING
+                    )
+                    PARTITIONED BY (tenant string, ymd string)
+                    STORED AS JSON
+                    LOCATION 's3://okera-trial-us-west-2-e71015d/tenants/logs/analytics/'
+                    ''' % db)
+                conn.execute_ddl(
+                    'ALTER TABLE %s.audit_logs RECOVER PARTITIONS' %  db)
+                conn.execute_ddl(
+                    'ALTER TABLE %s.web_analytics RECOVER PARTITIONS' % db)
+            PERF.measure(recover, 'recover partition with many folders and files',
+                         None, '', iters=5)
+
+            def show():
+                res = conn.execute_ddl('SHOW PARTITIONS %s.audit_logs' % db)
+                self.assertTrue(len(res) > 2000)
+            def show_files():
+                res = conn.execute_ddl('SHOW FILES IN %s.audit_logs' % db)
+            PERF.measure(show, 'show thousands partitions',
+                         None, '')
+            PERF.measure(show_files, 'show thousands files in partitions',
+                         None, '')
+
+    @unittest.skipIf(not PERF.run_perf(), "Skipping perf tests")
+    def test_list_table_names(self):
+        db = 'perf_test_large_db'
+        ctx = common.get_test_context()
+        role = 'perf_test_large_db_role'
+        user = 'perf_test_large_db_user'
+        with common.get_planner(ctx) as conn:
+            self._recreate_test_role(conn, role, [user])
+            conn.delete_attribute(db, 'financial')
+            conn.create_attribute(db, 'financial')
+            conn.delete_attribute(db, 'phone_number')
+            conn.create_attribute(db, 'phone_number')
+            conn.delete_attribute(db, 'credit_card')
+            conn.create_attribute(db, 'credit_card')
+            create_test_data.create_large_db_wide_tables_attributes(conn, db, 1000)
+            conn.execute_ddl(('GRANT SELECT ON CATALOG ' +
+                              'HAVING ATTRIBUTE NOT IN (%s.financial) ' +
+                              'TRANSFORM %s.email WITH sha2() ' +
+                              'TRANSFORM %s.phone_number WITH sha2() ' +
+                              'TRANSFORM %s.credit_card WITH mask() ' +
+                              'TRANSFORM %s.person WITH mask() ' +
+                              'TO ROLE %s') % (db, db, db, db, db, role))
+
+            def ls():
+                conn.list_dataset_names(db)
+
+            PERF.measure(ls, "Many wide tables", "admin", "list_dataset_names")
+
+            ctx.enable_token_auth(token_str=user)
+            PERF.measure(ls, "Many wide tables", "testuser", "list_dataset_names")
+
+
     # TODO: missing RPCs
     # TExecDDLResult ExecuteDDL2(1:TExecDDLParams ddl)
     # throws(1:RecordService.TRecordServiceException ex);
