@@ -1505,6 +1505,7 @@ class RolesTest(common.TestBase):
                       },
                       {
                         "type": "LITERAL",
+                        "node_type": "STRING_LITERAL",
                         "sql": "abc"
                       }
                     ],
@@ -1534,7 +1535,8 @@ class RolesTest(common.TestBase):
               "children": [
                 {
                   "sql": "NULL",
-                  "type": "LITERAL"
+                  "type": "LITERAL",
+                  "node_type": "NULL_LITERAL"
                 },
                 {
                   "sql": "get_role_ns.get_role_attr",
